[clinfo] 43/55: Fix new-version.sh script after f98c9ede8

Andreas Beckmann anbe at moszumanska.debian.org
Sat Jan 13 14:40:02 UTC 2018


This is an automated email from the git hooks/post-receive script.

anbe pushed a commit to branch master
in repository clinfo.

commit d48f6c60df75c92171c10da265e23e72c3d61eb5
Author: Giuseppe Bilotta <giuseppe.bilotta at gmail.com>
Date:   Wed Oct 25 21:50:14 2017 +0200

    Fix new-version.sh script after f98c9ede8
    
    The man page has changed location.
---
 new-version.sh | 9 ++++-----
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/new-version.sh b/new-version.sh
index 4fa0dc1..271fe88 100755
--- a/new-version.sh
+++ b/new-version.sh
@@ -1,6 +1,6 @@
 #!/bin/sh
 
 # Change the version recorded in src/clinfo.c and man/clinfo.1 to
 # the current highest OpenCL supported standard followed by current
 # yy.mm.dd
 
@@ -12,13 +12,12 @@ abort() {
 test -n "$(git status --porcelain | grep -v '??')" && abort "Uncommited changes, aborting"
 
 DATE=$(date +%Y-%m-%d)
-MAJOR=$(awk '/^OpenCL/ { print $NF ; quit }' man/clinfo.1)
+MAJOR=$(awk '/^OpenCL/ { print $NF ; quit }' man1/clinfo.1)
 SUBV=$(date +%y.%m.%d)
 VERSION="$MAJOR$SUBV"
 
 
-sed -i -e "/clinfo version/ s/version \S\+\"/version $VERSION\"/" src/clinfo.c
-sed -i -e "1 s/\".\+$/\"$DATE\" \"clinfo $VERSION\"/" man/clinfo.1
-
+sed -i -e "/clinfo version/ s/version \S\+\"/version $VERSION\"/" src/clinfo.c &&
+sed -i -e "1 s/\".\+$/\"$DATE\" \"clinfo $VERSION\"/" man1/clinfo.1 &&
 git commit -m "Version $VERSION" -e -a && git tag -m "Version $VERSION" $VERSION
 
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Change the version recorded in src/clinfo.c and man/clinfo.1 to
+# Change the version recorded in src/clinfo.c and man1/clinfo.1 to
 # the current highest OpenCL supported standard followed by current
 # yy.mm.dd

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-opencl/clinfo.git



More information about the Pkg-opencl-commits mailing list